@@ -1,19 +1,29 @@
 #include <RcppArmadillo.h>
 // [[Rcpp::depends(RcppArmadillo)]]
 
-//' Sum Within Distance (Spatially Balanced Sampling).
+//' Sum Within Distance (Spatially Balanced Sampling Design)
 //'
-//' This is an implemention of a spatially balanced design, with a probability function proportional to the within sample distance, using the sum of distance as an index of the within sample distance (Sum Within Distance, \code{swd} in short).
-//' To have a constant inclusion probabilities \eqn{\pi_{i}=nsamp/N}, where \eqn{nsamp} is sample size and \eqn{N} is population size, standardize the distance matrix with function \code{\link{stsum}}.
+//' Selects spatially balanced samples through the use of the
+//' Sum Within Distance design (SWD). To have a constant inclusion
+//' probabilities \eqn{\pi_{i}=nsamp/N}, where \eqn{nsamp} is sample size and
+//' \eqn{N} is population size, the distance matrix has to be standardized with
+//' function \code{\link{stsum}}.
 //'
-//' @param dis A distance matrix NxN that specifies how far are all the pairs of units in the population.
+//' @param dis A distance matrix NxN that specifies how far are all the pairs
+//' of units in the population.
 //' @param nsamp Sample size.
-//' @param bexp Parameter \eqn{\beta} for the algorithm. The higher \eqn{\beta} is, the more the sample is going to be spread.
+//' @param bexp Parameter \eqn{\beta} for the algorithm. The higher
+//' \eqn{\beta} is, the more the sample is going to be spread.
 //' @param nrepl Number of samples to draw (default = 1).
-//' @param niter Number of iterations for the algorithm. More iterations are better but require more time. Usually 10 is very efficient (default = 10).
-//' @return Return a matrix 2 x \code{nrepl} with \code{nrepl} samples drawn. In particular, the element \eqn{a_{ij}}{a_ij} is the j-th unit of the population drawn in the i-th sample.
+//' @param niter Number of iterations for the algorithm. More iterations are
+//' better but require more time. Usually 10 is very efficient (default = 10).
+//' @return Return a matrix \code{nrepl} x \code{nsamp}, which contains the
+//' \code{nrepl} selected samples, each of them stored in a row. In particular,
+//' the i-th row contains all labels of units selected in the i-th sample.
 //' @references
-//' \insertRef{BIMJ:BIMJ1785}{Spbsampling}
+//' Benedetti R, Piersimoni F (2017). “A spatially balanced design with
+//' probability function proportional to the within sample distance.”
+//' \emph{Biometrical Journal}, \strong{59}(5), 1067–1084.
 //' @examples
 //' # Example 1
 //' # Draw 20 samples of dimension 15 without constant probabilities and beta = 1
@@ -31,7 +41,7 @@
 //' nsamp <- 15  # sample size
 //' nrepl <- 20  # numbers of samples to drawn
 //' niter <- 10  # numbers of iterations in the algorithm
-//' bexp <- 10  # parameter beta
+//' bexp <- 10   # parameter beta
 //' vec <- rep(1, nrow(dis)) # vector of constraints
 //' stand_dist <- stsum(dis, vec, 1e-15, 1000) # standardized matrix
 //' samples <- swd(stand_dist, niter, nsamp, nrepl, bexp)  # drawn samples
@@ -70,7 +80,7 @@ arma::mat swd (arma::mat dis, int nsamp, int bexp, int nrepl = 1, int niter = 10
   {
     throw Rcpp::exception("niter has to be greater than 0");
   }
-  arma::mat selez(nsamp * nrepl, 2);
+  arma::mat selez(nrepl, nsamp);
   arma::vec ord(npo);
   arma::vec codord(npo);
   arma::vec gcod(npo * 3);
@@ -117,16 +127,7 @@ arma::mat swd (arma::mat dis, int nsamp, int bexp, int nrepl = 1, int niter = 10
       }
       iter++;
     }
-    for (int i=((cc - 1) * nsamp); i < (cc * nsamp); i++)
-    {
-      selez(i, 0) = cc;
-    }
-    int j = 0;
-    for (int i = ((cc - 1) * nsamp); i < (cc * nsamp); i++)
-    {
-      selez(i, 1) = codord(j);
-      j++;
-    }
+    selez.row(cc - 1) = codord.subvec(0, nsamp - 1).t();
   }
   return selez;
 }
